<?php

namespace Elementor;

use Elementor\Controls_Manager;
use Elementor\Core\Base\Document;
use Elementor\Core\Base\Module as BaseModule;
use Elementor\Plugin;
use Elementor\Utils;
use Elementor\Core\DocumentTypes\PageBase as PageBase;
use Elementor\Modules\Library\Documents\Page as LibraryPageDocument;

if( !defined( 'ABSPATH' ) ) exit;

class Styler_Customizing_Page_Settings {
    use Styler_Helper;
    private static $instance = null;

    public static function get_instance() {
        if ( null == self::$instance ) {
            self::$instance = new Styler_Customizing_Page_Settings();
        }
        return self::$instance;
    }

    public function __construct(){
        
        add_action( 'elementor/documents/register_controls',[ $this,'styler_page_settings'], 10 );
    }

    public function styler_page_settings( $document )
    {
        $document->start_controls_section( 'styler_page_header_settings',
            [
                'label' => esc_html__( 'STYLER PAGE HEADER-FOOTER', 'styler' ),
                'tab' => Controls_Manager::TAB_SETTINGS,
                'separator' => 'before'
            ]
        );
        $document->add_control( 'styler_page_header_settings_heading',
            [
                'label' => esc_html__( 'STYLER PAGE HEADER', 'styler' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $document->add_control( 'styler_hide_page_header',
            [
                'label' => esc_html__( 'Hide Page Header', 'styler' ),
                'type' => Controls_Manager::SWITCHER,
                'return_value' => 'yes',
                'default' => 'no'
            ]
        );
        $document->add_control( 'styler_page_header_template',
            [
                'label' => esc_html__( 'Select Header Template', 'styler' ),
                'type' => Controls_Manager::SELECT2,
                'default' => '',
                'multiple' => false,
                'options' => $this->styler_get_elementor_templates(),
                'condition' => [ 'styler_hide_page_header!' => 'yes' ]
            ]
        );
        $document->add_control( 'styler_page_footer_settings_heading',
            [
                'label' => esc_html__( 'STYLER PAGE FOOTER', 'styler' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        $document->add_control( 'styler_hide_page_footer',
            [
                'label' => esc_html__( 'Hide Footer', 'styler' ),
                'type' => Controls_Manager::SWITCHER,
                'return_value' => 'yes',
                'default' => 'no'
            ]
        );
        $document->add_control( 'styler_page_footer_template',
            [
                'label' => esc_html__( 'Select Footer Template', 'styler' ),
                'type' => Controls_Manager::SELECT2,
                'default' => '',
                'multiple' => false,
                'options' => $this->styler_get_elementor_templates(),
                'condition' => [ 'styler_hide_page_footer!' => 'yes' ]
            ]
        );
        $document->end_controls_section();

    }

    public function styler_add_custom_css_to_page_settings( $page )
    {

        if ( isset($page) && $page->get_id() > "" ){

            $nt_post_type = false;
            $nt_post_type = get_post_type($page->get_id());

            if ( $nt_post_type == 'page' || $nt_post_type == 'revision' ) {

                $page->start_controls_section( 'header_custom_css_controls_section',
                    [
                        'label' => esc_html__( 'STYLER PAGE CUSTOM CSS', 'styler' ),
                        'tab' => Controls_Manager::TAB_SETTINGS
                    ]
                );
                $page->add_control( 'styler_page_custom_css',
                    [
                        'label' => esc_html__( 'Custom CSS', 'styler' ),
                        'type' => Controls_Manager::CODE,
                        'language' => 'css',
                        'rows' => 20
                    ]
                );
                $page->end_controls_section();
            }
        }
    }

    public function styler_page_registered_nav_menus()
    {
        $menus = wp_get_nav_menus();
        $options = array();
        if ( ! empty( $menus ) && ! is_wp_error( $menus ) ) {
            foreach ( $menus as $menu ) {
                $options[ $menu->slug ] = $menu->name;
            }
        }
        return $options;
    }
}
Styler_Customizing_Page_Settings::get_instance();
